# Gemini Pong

**Pong** game with Google Gemini AI integrated into it.

# Source Code

The source code of the game **Gemini Pong** is available in [Source Code](https://github.com/SoftwareApkDev/gemini_pong/blob/master/gemini_pong/gemini_pong.py).

# Installation

```
pip install gemini_pong
```

# How to Run the Game?

Pre-requisites:

1. [Python](https://www.python.org/downloads/) installed in your device.
2. .env file in the same directory as <GEMINI_PONG_DIRECTORY> and has the value of GEMINI_API_KEY.

```
cd <GEMINI_PONG_DIRECTORY>
python gemini_pong.py
```

**Note:** Replace <GEMINI_PONG_DIRECTORY> with the path to the directory of the game **Gemini Pong**.

Then, the game will start like as follows.

![Gameplay](images/Gameplay.png)

The player uses the paddle on the left side of the screen. Press the "UP" and "DOWN" keys to move the paddle.
